package com.fastbee.iot.mapper;

import java.util.List;
import com.fastbee.iot.domain.NgDeviceOperationRecords;
import org.springframework.stereotype.Repository;

/**
 * 设备操作记录Mapper接口
 *
 * @author kerwincui
 * @date 2024-12-30
 */
@Repository
public interface NgDeviceOperationRecordsMapper
{
    /**
     * 查询设备操作记录
     *
     * @param id 设备操作记录主键
     * @return 设备操作记录
     */
    public NgDeviceOperationRecords selectNgDeviceOperationRecordsById(Long id);

    /**
     * 查询设备操作记录列表
     *
     * @param ngDeviceOperationRecords 设备操作记录
     * @return 设备操作记录集合
     */
    public List<NgDeviceOperationRecords> selectNgDeviceOperationRecordsList(NgDeviceOperationRecords ngDeviceOperationRecords);

    /**
     * 新增设备操作记录
     *
     * @param ngDeviceOperationRecords 设备操作记录
     * @return 结果
     */
    public int insertNgDeviceOperationRecords(NgDeviceOperationRecords ngDeviceOperationRecords);

    /**
     * 修改设备操作记录
     *
     * @param ngDeviceOperationRecords 设备操作记录
     * @return 结果
     */
    public int updateNgDeviceOperationRecords(NgDeviceOperationRecords ngDeviceOperationRecords);

    /**
     * 删除设备操作记录
     *
     * @param id 设备操作记录主键
     * @return 结果
     */
    public int deleteNgDeviceOperationRecordsById(Long id);

    /**
     * 批量删除设备操作记录
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteNgDeviceOperationRecordsByIds(Long[] ids);
}
